# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.  Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

    The version of the OpenAPI document: 1.3.8815
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ourskyai_sda_api.models.v1_organization_target import V1OrganizationTarget  # noqa: E501

class TestV1OrganizationTarget(unittest.TestCase):
    """V1OrganizationTarget unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1OrganizationTarget:
        """Test V1OrganizationTarget
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1OrganizationTarget`
        """
        model = V1OrganizationTarget()  # noqa: E501
        if include_optional:
            return V1OrganizationTarget(
                id = '',
                revisit_rate_minutes = 56,
                satellite_target = ourskyai_sda_api.models.v1_satellite_target.V1SatelliteTarget(
                    id = '', 
                    cospar_id = '', 
                    norad_id = '', 
                    orbit_type = 'GEOSTATIONARY', 
                    tle_epoch = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    tle_name = '', 
                    tle_line1 = '', 
                    tle_line2 = '', 
                    tracking_status = 'ACTIVE', 
                    classification = '', 
                    launch_year = 56, 
                    epoch_year = 56, 
                    epoch_day = 56, 
                    mean_motion_first_derivative = 1.337, 
                    mean_motion_second_derivative = 1.337, 
                    bstar = 1.337, 
                    ephemeris_type = 56, 
                    element_number = 56, 
                    inclination = 1.337, 
                    raan = 1.337, 
                    eccentricity = 1.337, 
                    perigee_argument = 1.337, 
                    mean_anomaly = 1.337, 
                    mean_motion = 1.337, 
                    revolution_number_at_epoch = 56, 
                    organization_id = '', 
                    coefficient_of_reflection = 1.337, 
                    mass = 1.337, 
                    area = 1.337, 
                    linked_satellite_target_id = '', 
                    orbit_source_id = '', 
                    orbit_source_provider_name = '', ),
                created_by = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return V1OrganizationTarget(
                id = '',
                satellite_target = ourskyai_sda_api.models.v1_satellite_target.V1SatelliteTarget(
                    id = '', 
                    cospar_id = '', 
                    norad_id = '', 
                    orbit_type = 'GEOSTATIONARY', 
                    tle_epoch = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    tle_name = '', 
                    tle_line1 = '', 
                    tle_line2 = '', 
                    tracking_status = 'ACTIVE', 
                    classification = '', 
                    launch_year = 56, 
                    epoch_year = 56, 
                    epoch_day = 56, 
                    mean_motion_first_derivative = 1.337, 
                    mean_motion_second_derivative = 1.337, 
                    bstar = 1.337, 
                    ephemeris_type = 56, 
                    element_number = 56, 
                    inclination = 1.337, 
                    raan = 1.337, 
                    eccentricity = 1.337, 
                    perigee_argument = 1.337, 
                    mean_anomaly = 1.337, 
                    mean_motion = 1.337, 
                    revolution_number_at_epoch = 56, 
                    organization_id = '', 
                    coefficient_of_reflection = 1.337, 
                    mass = 1.337, 
                    area = 1.337, 
                    linked_satellite_target_id = '', 
                    orbit_source_id = '', 
                    orbit_source_provider_name = '', ),
                created_by = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testV1OrganizationTarget(self):
        """Test V1OrganizationTarget"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
